# nikkiepy
Custom python library

## Current features

### Sockets
* connection_test(host=host, port=port)

##### Examples:
###### `nikkiepy.connection_test(host="127.0.0.1", port=5000)` Output: ```Connects and inmediately disconnects from host, used to test connection```
##### Notes:
###### * None *for now*

### files
* mkfile(path, name, extension)
* delfile(file)
* delfolder(folder)
##### Examples:
###### `nikkiepy.mkfile(path="E:/coding/testing/python", name="testfile", extension="txt")` Output: ```File: testfile.txt has been made in E:/coding/testing/python```
###### `nikkiepy.delfile(file="E:/coding/testing/python/testfile.txt")` Output: ```File: testfile.txt successfully deleted!```
###### `nikkiepy.delfolder(folder="E:/coding/testing")` Output: ```Folder: testing has been successfully deleted!```
##### Notes:
###### * None *for now*



# CREATED BY NikkieDev
## Discord: Nikkiedev#6322
## Business contact: nikkieschaad@gmail.com
